# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: econ_shared_enums.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='econ_shared_enums.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\x17\x65\x63on_shared_enums.proto\">\n\x11\x43MsgGenericResult\x12\x12\n\x07\x65result\x18\x01 \x01(\r:\x01\x32\x12\x15\n\rdebug_message\x18\x02 \x01(\t*,\n\x0e\x45GCEconBaseMsg\x12\x1a\n\x15k_EMsgGCGenericResult\x10\x93\x14*\x9b\x02\n\x0e\x45GCMsgResponse\x12\x16\n\x12k_EGCMsgResponseOK\x10\x00\x12\x1a\n\x16k_EGCMsgResponseDenied\x10\x01\x12\x1f\n\x1bk_EGCMsgResponseServerError\x10\x02\x12\x1b\n\x17k_EGCMsgResponseTimeout\x10\x03\x12\x1b\n\x17k_EGCMsgResponseInvalid\x10\x04\x12\x1b\n\x17k_EGCMsgResponseNoMatch\x10\x05\x12 \n\x1ck_EGCMsgResponseUnknownError\x10\x06\x12\x1f\n\x1bk_EGCMsgResponseNotLoggedOn\x10\x07\x12\x1a\n\x16k_EGCMsgFailedToCreate\x10\x08*\xa2\x01\n\x19\x45GCPartnerRequestResponse\x12\x17\n\x13k_EPartnerRequestOK\x10\x01\x12\x1f\n\x1bk_EPartnerRequestBadAccount\x10\x02\x12\x1e\n\x1ak_EPartnerRequestNotLinked\x10\x03\x12+\n\'k_EPartnerRequestUnsupportedPartnerType\x10\x04*\xc5\x05\n\x15\x45GCMsgUseItemResponse\x12$\n k_EGCMsgUseItemResponse_ItemUsed\x10\x00\x12.\n*k_EGCMsgUseItemResponse_GiftNoOtherPlayers\x10\x01\x12\'\n#k_EGCMsgUseItemResponse_ServerError\x10\x02\x12\x32\n.k_EGCMsgUseItemResponse_MiniGameAlreadyStarted\x10\x03\x12\x31\n-k_EGCMsgUseItemResponse_ItemUsed_ItemsGranted\x10\x04\x12\x37\n3k_EGCMsgUseItemResponse_DropRateBonusAlreadyGranted\x10\x05\x12\x30\n,k_EGCMsgUseItemResponse_NotInLowPriorityPool\x10\x06\x12.\n*k_EGCMsgUseItemResponse_NotHighEnoughLevel\x10\x07\x12*\n&k_EGCMsgUseItemResponse_EventNotActive\x10\x08\x12\x37\n3k_EGCMsgUseItemResponse_ItemUsed_EventPointsGranted\x10\t\x12.\n*k_EGCMsgUseItemResponse_MissingRequirement\x10\n\x12\x30\n,k_EGCMsgUseItemResponse_EmoticonUnlock_NoNew\x10\x0b\x12\x33\n/k_EGCMsgUseItemResponse_EmoticonUnlock_Complete\x10\x0c\x12/\n+k_EGCMsgUseItemResponse_ItemUsed_Compendium\x10\rB\x05H\x01\x90\x01\x00')
)
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

_EGCECONBASEMSG = _descriptor.EnumDescriptor(
  name='EGCEconBaseMsg',
  full_name='EGCEconBaseMsg',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EMsgGCGenericResult', index=0, number=2579,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=91,
  serialized_end=135,
)
_sym_db.RegisterEnumDescriptor(_EGCECONBASEMSG)

EGCEconBaseMsg = enum_type_wrapper.EnumTypeWrapper(_EGCECONBASEMSG)
_EGCMSGRESPONSE = _descriptor.EnumDescriptor(
  name='EGCMsgResponse',
  full_name='EGCMsgResponse',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgResponseOK', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgResponseDenied', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgResponseServerError', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgResponseTimeout', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgResponseInvalid', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgResponseNoMatch', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgResponseUnknownError', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgResponseNotLoggedOn', index=7, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgFailedToCreate', index=8, number=8,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=138,
  serialized_end=421,
)
_sym_db.RegisterEnumDescriptor(_EGCMSGRESPONSE)

EGCMsgResponse = enum_type_wrapper.EnumTypeWrapper(_EGCMSGRESPONSE)
_EGCPARTNERREQUESTRESPONSE = _descriptor.EnumDescriptor(
  name='EGCPartnerRequestResponse',
  full_name='EGCPartnerRequestResponse',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EPartnerRequestOK', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EPartnerRequestBadAccount', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EPartnerRequestNotLinked', index=2, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EPartnerRequestUnsupportedPartnerType', index=3, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=424,
  serialized_end=586,
)
_sym_db.RegisterEnumDescriptor(_EGCPARTNERREQUESTRESPONSE)

EGCPartnerRequestResponse = enum_type_wrapper.EnumTypeWrapper(_EGCPARTNERREQUESTRESPONSE)
_EGCMSGUSEITEMRESPONSE = _descriptor.EnumDescriptor(
  name='EGCMsgUseItemResponse',
  full_name='EGCMsgUseItemResponse',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgUseItemResponse_ItemUsed', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgUseItemResponse_GiftNoOtherPlayers', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgUseItemResponse_ServerError', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgUseItemResponse_MiniGameAlreadyStarted', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgUseItemResponse_ItemUsed_ItemsGranted', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgUseItemResponse_DropRateBonusAlreadyGranted', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgUseItemResponse_NotInLowPriorityPool', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgUseItemResponse_NotHighEnoughLevel', index=7, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgUseItemResponse_EventNotActive', index=8, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgUseItemResponse_ItemUsed_EventPointsGranted', index=9, number=9,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgUseItemResponse_MissingRequirement', index=10, number=10,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgUseItemResponse_EmoticonUnlock_NoNew', index=11, number=11,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgUseItemResponse_EmoticonUnlock_Complete', index=12, number=12,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='k_EGCMsgUseItemResponse_ItemUsed_Compendium', index=13, number=13,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=589,
  serialized_end=1298,
)
_sym_db.RegisterEnumDescriptor(_EGCMSGUSEITEMRESPONSE)

EGCMsgUseItemResponse = enum_type_wrapper.EnumTypeWrapper(_EGCMSGUSEITEMRESPONSE)
k_EMsgGCGenericResult = 2579
k_EGCMsgResponseOK = 0
k_EGCMsgResponseDenied = 1
k_EGCMsgResponseServerError = 2
k_EGCMsgResponseTimeout = 3
k_EGCMsgResponseInvalid = 4
k_EGCMsgResponseNoMatch = 5
k_EGCMsgResponseUnknownError = 6
k_EGCMsgResponseNotLoggedOn = 7
k_EGCMsgFailedToCreate = 8
k_EPartnerRequestOK = 1
k_EPartnerRequestBadAccount = 2
k_EPartnerRequestNotLinked = 3
k_EPartnerRequestUnsupportedPartnerType = 4
k_EGCMsgUseItemResponse_ItemUsed = 0
k_EGCMsgUseItemResponse_GiftNoOtherPlayers = 1
k_EGCMsgUseItemResponse_ServerError = 2
k_EGCMsgUseItemResponse_MiniGameAlreadyStarted = 3
k_EGCMsgUseItemResponse_ItemUsed_ItemsGranted = 4
k_EGCMsgUseItemResponse_DropRateBonusAlreadyGranted = 5
k_EGCMsgUseItemResponse_NotInLowPriorityPool = 6
k_EGCMsgUseItemResponse_NotHighEnoughLevel = 7
k_EGCMsgUseItemResponse_EventNotActive = 8
k_EGCMsgUseItemResponse_ItemUsed_EventPointsGranted = 9
k_EGCMsgUseItemResponse_MissingRequirement = 10
k_EGCMsgUseItemResponse_EmoticonUnlock_NoNew = 11
k_EGCMsgUseItemResponse_EmoticonUnlock_Complete = 12
k_EGCMsgUseItemResponse_ItemUsed_Compendium = 13



_CMSGGENERICRESULT = _descriptor.Descriptor(
  name='CMsgGenericResult',
  full_name='CMsgGenericResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='eresult', full_name='CMsgGenericResult.eresult', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='debug_message', full_name='CMsgGenericResult.debug_message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=27,
  serialized_end=89,
)

DESCRIPTOR.message_types_by_name['CMsgGenericResult'] = _CMSGGENERICRESULT
DESCRIPTOR.enum_types_by_name['EGCEconBaseMsg'] = _EGCECONBASEMSG
DESCRIPTOR.enum_types_by_name['EGCMsgResponse'] = _EGCMSGRESPONSE
DESCRIPTOR.enum_types_by_name['EGCPartnerRequestResponse'] = _EGCPARTNERREQUESTRESPONSE
DESCRIPTOR.enum_types_by_name['EGCMsgUseItemResponse'] = _EGCMSGUSEITEMRESPONSE

CMsgGenericResult = _reflection.GeneratedProtocolMessageType('CMsgGenericResult', (_message.Message,), dict(
  DESCRIPTOR = _CMSGGENERICRESULT,
  __module__ = 'econ_shared_enums_pb2'
  # @@protoc_insertion_point(class_scope:CMsgGenericResult)
  ))
_sym_db.RegisterMessage(CMsgGenericResult)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('H\001\220\001\000'))
# @@protoc_insertion_point(module_scope)
